--- include/miiphy.h.orig	2004-04-19 09:20:01.000000000 -0700
+++ include/miiphy.h	2004-04-19 09:58:28.000000000 -0700
@@ -93,6 +93,11 @@ int  miiphy_link(unsigned char addr);
 #define PHY_BMCR_DPLX		0x0100
 #define PHY_BMCR_COL_TST	0x0080
 
+#define PHY_BMCR_SPEED_MASK     0x2040
+#define PHY_BMCR_1000_MBPS      0x0040
+#define PHY_BMCR_100_MBPS       0x2000
+#define PHY_BMCR_10_MBPS        0x0000
+
 /* phy BMSR */
 #define PHY_BMSR_100T4		0x8000
 #define PHY_BMSR_100TXF		0x4000
@@ -118,6 +123,10 @@ int  miiphy_link(unsigned char addr);
 #define PHY_ANLPAR_10		0x0020
 #define PHY_ANLPAR_100		0x0380	    /* we can run at 100 */
 
+#define PHY_ANLPAR_PSB_MASK     0x001f
+#define PHY_ANLPAR_PSB_802_3    0x0001
+#define PHY_ANLPAR_PSB_802_9    0x0002
+
 /* PHY_1000BTSR */
 #define PHY_1000BTSR_MSCF       0x8000
 #define PHY_1000BTSR_MSCR       0x4000
--- common/cmd_mii.c.1	2004-04-19 09:07:20.000000000 -0700
+++ common/cmd_mii.c	2004-04-19 10:00:18.000000000 -0700
@@ -28,7 +28,6 @@
 #include <common.h>
 #include <command.h>
 #include <miiphy.h>
-#include <miivals.h>
 
 #if (CONFIG_COMMANDS & CFG_CMD_MII)
 
@@ -343,14 +342,14 @@ static int special_field(
 	ushort regval)
 {
 	if ((regno == 0) && (pdesc->lo == 6)) {
-		ushort speed_bits = regval & MII_CTL_SPEED_MASK;
+		ushort speed_bits = regval & PHY_BMCR_SPEED_MASK;
 		printf("%2u,%2u =   b%u%u    speed selection = %s Mbps",
 			6, 13,
 			(regval >>  6) & 1,
 			(regval >> 13) & 1,
-			speed_bits == MII_CTL_SPEED_1000_MBPS ? "1000" :
-			speed_bits == MII_CTL_SPEED_100_MBPS  ? "100" :
-			speed_bits == MII_CTL_SPEED_10_MBPS   ? "10" :
+			speed_bits == PHY_BMCR_1000_MBPS ? "1000" :
+			speed_bits == PHY_BMCR_100_MBPS  ? "100" :
+			speed_bits == PHY_BMCR_10_MBPS   ? "10" :
 			"???");
 		return 1;
 	}
@@ -367,9 +366,9 @@ static int special_field(
 		ushort sel_bits = (regval >> pdesc->lo) & pdesc->mask;
 		printf("%2u-%2u = %5u    selector = %s",
 			pdesc->hi, pdesc->lo, sel_bits,
-			sel_bits == MII_AN_ADV_IEEE_802_3 ?
+			sel_bits == PHY_ANLPAR_PSB_802_3 ?
 				"IEEE 802.3" :
-			sel_bits == MII_AN_ADV_IEEE_802_9_ISLAN_16T ?
+			sel_bits == PHY_ANLPAR_PSB_802_9 ?
 				"IEEE 802.9 ISLAN-16T" :
 			"???");
 		return 1;
@@ -379,9 +378,9 @@ static int special_field(
 		ushort sel_bits = (regval >> pdesc->lo) & pdesc->mask;
 		printf("%2u-%2u =     %u    selector = %s",
 			pdesc->hi, pdesc->lo, sel_bits,
-			sel_bits == MII_AN_PARTNER_IEEE_802_3 ?
+			sel_bits == PHY_ANLPAR_PSB_802_3 ?
 				"IEEE 802.3" :
-			sel_bits == MII_AN_PARTNER_IEEE_802_9_ISLAN_16T ?
+			sel_bits == PHY_ANLPAR_PSB_802_9 ?
 				"IEEE 802.9 ISLAN-16T" :
 			"???");
 		return 1;
@@ -418,7 +417,7 @@ int do_mii (cmd_tbl_t * cmdtp, int flag,
 {
 	char		op;
 	unsigned char	addrlo, addrhi, reglo, reghi;
-	unsigned char	addr, reg;
+	unsigned char	addr = 0, reg = 0;
 	unsigned short	data;
 	int		rcode = 0;
 
